==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/FormatLinearGraphLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatLinearGraphLabelEventArgsDescription } from "./FormatLinearGraphLabelEventArgsDescription";
/**
 * @hidden
 */
export let FormatLinearGraphLabelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatLinearGraphLabelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FormatLinearGraphLabelEventArgsDescriptionMetadata.a == null) {
                FormatLinearGraphLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatLinearGraphLabelEventArgsDescriptionMetadata.c(FormatLinearGraphLabelEventArgsDescriptionMetadata.a);
            }
            if (a.k(FormatLinearGraphLabelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(FormatLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FormatLinearGraphLabelEventArgsDescriptionMetadata.b(a);
            a.ad("FormatLinearGraphLabelEventArgs", () => new FormatLinearGraphLabelEventArgsDescription());
            a.ac("FormatLinearGraphLabelEventArgs", FormatLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
    }
    FormatLinearGraphLabelEventArgsDescriptionMetadata.$t = markType(FormatLinearGraphLabelEventArgsDescriptionMetadata, 'FormatLinearGraphLabelEventArgsDescriptionMetadata');
    FormatLinearGraphLabelEventArgsDescriptionMetadata.a = null;
    return FormatLinearGraphLabelEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/FormatLinearGraphLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatLinearGraphLabelEventArgsDescription } from "./FormatLinearGraphLabelEventArgsDescription";
/**
 * @hidden
 */
export let FormatLinearGraphLabelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FormatLinearGraphLabelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FormatLinearGraphLabelEventArgsDescriptionMetadata.a == null) {
                FormatLinearGraphLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FormatLinearGraphLabelEventArgsDescriptionMetadata.c(FormatLinearGraphLabelEventArgsDescriptionMetadata.a);
            }
            if (a.k(FormatLinearGraphLabelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(FormatLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FormatLinearGraphLabelEventArgsDescriptionMetadata.b(a);
            a.ae("FormatLinearGraphLabelEventArgs", () => new FormatLinearGraphLabelEventArgsDescription());
            a.ad("FormatLinearGraphLabelEventArgs", FormatLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
    }
    FormatLinearGraphLabelEventArgsDescriptionMetadata.$t = markType(FormatLinearGraphLabelEventArgsDescriptionMetadata, 'FormatLinearGraphLabelEventArgsDescriptionMetadata');
    FormatLinearGraphLabelEventArgsDescriptionMetadata.a = null;
    return FormatLinearGraphLabelEventArgsDescriptionMetadata;
})();
